import { Component, type Entity, Material, SensorComponent, GraphicsComponent, Optional } from "prototwin";

/**
 * This controller changes the material of a sensor to indicate whether the sensor is blocked or cleared.
 */
export class SensorController extends Component {
    @Optional(Material)
    public blocked: Material|null = null;
    @Optional(Material)
    public cleared: Material|null = null;
    
    constructor(entity: Entity) {
        super(entity);
    }

    public override initialize() {
        const self = this;
        const graphics = this.entity.component(GraphicsComponent);
        const sensor = this.entity.component(SensorComponent);
        graphics.material = (sensor.state) ? this.blocked : this.cleared;
        this.subscribe(this.entity.component(SensorComponent).io.state, function(state: boolean) {
            graphics.material = (state) ? self.blocked : self.cleared;
        });
    }
}
